# -*- coding: utf-8 -*-

from enum import Enum
from typing import Dict, Final, Union

import cv2

from cvlayer.enum.utils import make_name_map

COLOR_BGR2BGRA: Final[int] = cv2.COLOR_BGR2BGRA
COLOR_RGB2RGBA: Final[int] = cv2.COLOR_RGB2RGBA
COLOR_BGRA2BGR: Final[int] = cv2.COLOR_BGRA2BGR
COLOR_RGBA2RGB: Final[int] = cv2.COLOR_RGBA2RGB
COLOR_BGR2RGBA: Final[int] = cv2.COLOR_BGR2RGBA
COLOR_RGB2BGRA: Final[int] = cv2.COLOR_RGB2BGRA
COLOR_RGBA2BGR: Final[int] = cv2.COLOR_RGBA2BGR
COLOR_BGRA2RGB: Final[int] = cv2.COLOR_BGRA2RGB
COLOR_BGR2RGB: Final[int] = cv2.COLOR_BGR2RGB
COLOR_RGB2BGR: Final[int] = cv2.COLOR_RGB2BGR
COLOR_BGRA2RGBA: Final[int] = cv2.COLOR_BGRA2RGBA
COLOR_RGBA2BGRA: Final[int] = cv2.COLOR_RGBA2BGRA
COLOR_BGR2GRAY: Final[int] = cv2.COLOR_BGR2GRAY
COLOR_RGB2GRAY: Final[int] = cv2.COLOR_RGB2GRAY
COLOR_GRAY2BGR: Final[int] = cv2.COLOR_GRAY2BGR
COLOR_GRAY2RGB: Final[int] = cv2.COLOR_GRAY2RGB
COLOR_GRAY2BGRA: Final[int] = cv2.COLOR_GRAY2BGRA
COLOR_GRAY2RGBA: Final[int] = cv2.COLOR_GRAY2RGBA
COLOR_BGRA2GRAY: Final[int] = cv2.COLOR_BGRA2GRAY
COLOR_RGBA2GRAY: Final[int] = cv2.COLOR_RGBA2GRAY
COLOR_BGR2BGR565: Final[int] = cv2.COLOR_BGR2BGR565
COLOR_RGB2BGR565: Final[int] = cv2.COLOR_RGB2BGR565
COLOR_BGR5652BGR: Final[int] = cv2.COLOR_BGR5652BGR
COLOR_BGR5652RGB: Final[int] = cv2.COLOR_BGR5652RGB
COLOR_BGRA2BGR565: Final[int] = cv2.COLOR_BGRA2BGR565
COLOR_RGBA2BGR565: Final[int] = cv2.COLOR_RGBA2BGR565
COLOR_BGR5652BGRA: Final[int] = cv2.COLOR_BGR5652BGRA
COLOR_BGR5652RGBA: Final[int] = cv2.COLOR_BGR5652RGBA
COLOR_GRAY2BGR565: Final[int] = cv2.COLOR_GRAY2BGR565
COLOR_BGR5652GRAY: Final[int] = cv2.COLOR_BGR5652GRAY
COLOR_BGR2BGR555: Final[int] = cv2.COLOR_BGR2BGR555
COLOR_RGB2BGR555: Final[int] = cv2.COLOR_RGB2BGR555
COLOR_BGR5552BGR: Final[int] = cv2.COLOR_BGR5552BGR
COLOR_BGR5552RGB: Final[int] = cv2.COLOR_BGR5552RGB
COLOR_BGRA2BGR555: Final[int] = cv2.COLOR_BGRA2BGR555
COLOR_RGBA2BGR555: Final[int] = cv2.COLOR_RGBA2BGR555
COLOR_BGR5552BGRA: Final[int] = cv2.COLOR_BGR5552BGRA
COLOR_BGR5552RGBA: Final[int] = cv2.COLOR_BGR5552RGBA
COLOR_GRAY2BGR555: Final[int] = cv2.COLOR_GRAY2BGR555
COLOR_BGR5552GRAY: Final[int] = cv2.COLOR_BGR5552GRAY
COLOR_BGR2XYZ: Final[int] = cv2.COLOR_BGR2XYZ
COLOR_RGB2XYZ: Final[int] = cv2.COLOR_RGB2XYZ
COLOR_XYZ2BGR: Final[int] = cv2.COLOR_XYZ2BGR
COLOR_XYZ2RGB: Final[int] = cv2.COLOR_XYZ2RGB
COLOR_BGR2YCrCb: Final[int] = cv2.COLOR_BGR2YCrCb
COLOR_BGR2YCR_CB: Final[int] = cv2.COLOR_BGR2YCR_CB
COLOR_RGB2YCrCb: Final[int] = cv2.COLOR_RGB2YCrCb
COLOR_RGB2YCR_CB: Final[int] = cv2.COLOR_RGB2YCR_CB
COLOR_YCrCb2BGR: Final[int] = cv2.COLOR_YCrCb2BGR
COLOR_YCR_CB2BGR: Final[int] = cv2.COLOR_YCR_CB2BGR
COLOR_YCrCb2RGB: Final[int] = cv2.COLOR_YCrCb2RGB
COLOR_YCR_CB2RGB: Final[int] = cv2.COLOR_YCR_CB2RGB
COLOR_BGR2HSV: Final[int] = cv2.COLOR_BGR2HSV
COLOR_RGB2HSV: Final[int] = cv2.COLOR_RGB2HSV
COLOR_BGR2Lab: Final[int] = cv2.COLOR_BGR2Lab
COLOR_BGR2LAB: Final[int] = cv2.COLOR_BGR2LAB
COLOR_RGB2Lab: Final[int] = cv2.COLOR_RGB2Lab
COLOR_RGB2LAB: Final[int] = cv2.COLOR_RGB2LAB
COLOR_BGR2Luv: Final[int] = cv2.COLOR_BGR2Luv
COLOR_BGR2LUV: Final[int] = cv2.COLOR_BGR2LUV
COLOR_RGB2Luv: Final[int] = cv2.COLOR_RGB2Luv
COLOR_RGB2LUV: Final[int] = cv2.COLOR_RGB2LUV
COLOR_BGR2HLS: Final[int] = cv2.COLOR_BGR2HLS
COLOR_RGB2HLS: Final[int] = cv2.COLOR_RGB2HLS
COLOR_HSV2BGR: Final[int] = cv2.COLOR_HSV2BGR
COLOR_HSV2RGB: Final[int] = cv2.COLOR_HSV2RGB
COLOR_Lab2BGR: Final[int] = cv2.COLOR_Lab2BGR
COLOR_LAB2BGR: Final[int] = cv2.COLOR_LAB2BGR
COLOR_Lab2RGB: Final[int] = cv2.COLOR_Lab2RGB
COLOR_LAB2RGB: Final[int] = cv2.COLOR_LAB2RGB
COLOR_Luv2BGR: Final[int] = cv2.COLOR_Luv2BGR
COLOR_LUV2BGR: Final[int] = cv2.COLOR_LUV2BGR
COLOR_Luv2RGB: Final[int] = cv2.COLOR_Luv2RGB
COLOR_LUV2RGB: Final[int] = cv2.COLOR_LUV2RGB
COLOR_HLS2BGR: Final[int] = cv2.COLOR_HLS2BGR
COLOR_HLS2RGB: Final[int] = cv2.COLOR_HLS2RGB
COLOR_BGR2HSV_FULL: Final[int] = cv2.COLOR_BGR2HSV_FULL
COLOR_RGB2HSV_FULL: Final[int] = cv2.COLOR_RGB2HSV_FULL
COLOR_BGR2HLS_FULL: Final[int] = cv2.COLOR_BGR2HLS_FULL
COLOR_RGB2HLS_FULL: Final[int] = cv2.COLOR_RGB2HLS_FULL
COLOR_HSV2BGR_FULL: Final[int] = cv2.COLOR_HSV2BGR_FULL
COLOR_HSV2RGB_FULL: Final[int] = cv2.COLOR_HSV2RGB_FULL
COLOR_HLS2BGR_FULL: Final[int] = cv2.COLOR_HLS2BGR_FULL
COLOR_HLS2RGB_FULL: Final[int] = cv2.COLOR_HLS2RGB_FULL
COLOR_LBGR2Lab: Final[int] = cv2.COLOR_LBGR2Lab
COLOR_LBGR2LAB: Final[int] = cv2.COLOR_LBGR2LAB
COLOR_LRGB2Lab: Final[int] = cv2.COLOR_LRGB2Lab
COLOR_LRGB2LAB: Final[int] = cv2.COLOR_LRGB2LAB
COLOR_LBGR2Luv: Final[int] = cv2.COLOR_LBGR2Luv
COLOR_LBGR2LUV: Final[int] = cv2.COLOR_LBGR2LUV
COLOR_LRGB2Luv: Final[int] = cv2.COLOR_LRGB2Luv
COLOR_LRGB2LUV: Final[int] = cv2.COLOR_LRGB2LUV
COLOR_Lab2LBGR: Final[int] = cv2.COLOR_Lab2LBGR
COLOR_LAB2LBGR: Final[int] = cv2.COLOR_LAB2LBGR
COLOR_Lab2LRGB: Final[int] = cv2.COLOR_Lab2LRGB
COLOR_LAB2LRGB: Final[int] = cv2.COLOR_LAB2LRGB
COLOR_Luv2LBGR: Final[int] = cv2.COLOR_Luv2LBGR
COLOR_LUV2LBGR: Final[int] = cv2.COLOR_LUV2LBGR
COLOR_Luv2LRGB: Final[int] = cv2.COLOR_Luv2LRGB
COLOR_LUV2LRGB: Final[int] = cv2.COLOR_LUV2LRGB
COLOR_BGR2YUV: Final[int] = cv2.COLOR_BGR2YUV
COLOR_RGB2YUV: Final[int] = cv2.COLOR_RGB2YUV
COLOR_YUV2BGR: Final[int] = cv2.COLOR_YUV2BGR
COLOR_YUV2RGB: Final[int] = cv2.COLOR_YUV2RGB
COLOR_YUV2RGB_NV12: Final[int] = cv2.COLOR_YUV2RGB_NV12
COLOR_YUV2BGR_NV12: Final[int] = cv2.COLOR_YUV2BGR_NV12
COLOR_YUV2RGB_NV21: Final[int] = cv2.COLOR_YUV2RGB_NV21
COLOR_YUV2BGR_NV21: Final[int] = cv2.COLOR_YUV2BGR_NV21
COLOR_YUV420sp2RGB: Final[int] = cv2.COLOR_YUV420sp2RGB
COLOR_YUV420SP2RGB: Final[int] = cv2.COLOR_YUV420SP2RGB
COLOR_YUV420sp2BGR: Final[int] = cv2.COLOR_YUV420sp2BGR
COLOR_YUV420SP2BGR: Final[int] = cv2.COLOR_YUV420SP2BGR
COLOR_YUV2RGBA_NV12: Final[int] = cv2.COLOR_YUV2RGBA_NV12
COLOR_YUV2BGRA_NV12: Final[int] = cv2.COLOR_YUV2BGRA_NV12
COLOR_YUV2RGBA_NV21: Final[int] = cv2.COLOR_YUV2RGBA_NV21
COLOR_YUV2BGRA_NV21: Final[int] = cv2.COLOR_YUV2BGRA_NV21
COLOR_YUV420sp2RGBA: Final[int] = cv2.COLOR_YUV420sp2RGBA
COLOR_YUV420SP2RGBA: Final[int] = cv2.COLOR_YUV420SP2RGBA
COLOR_YUV420sp2BGRA: Final[int] = cv2.COLOR_YUV420sp2BGRA
COLOR_YUV420SP2BGRA: Final[int] = cv2.COLOR_YUV420SP2BGRA
COLOR_YUV2RGB_YV12: Final[int] = cv2.COLOR_YUV2RGB_YV12
COLOR_YUV2BGR_YV12: Final[int] = cv2.COLOR_YUV2BGR_YV12
COLOR_YUV2RGB_IYUV: Final[int] = cv2.COLOR_YUV2RGB_IYUV
COLOR_YUV2BGR_IYUV: Final[int] = cv2.COLOR_YUV2BGR_IYUV
COLOR_YUV2RGB_I420: Final[int] = cv2.COLOR_YUV2RGB_I420
COLOR_YUV2BGR_I420: Final[int] = cv2.COLOR_YUV2BGR_I420
COLOR_YUV420p2RGB: Final[int] = cv2.COLOR_YUV420p2RGB
COLOR_YUV420P2RGB: Final[int] = cv2.COLOR_YUV420P2RGB
COLOR_YUV420p2BGR: Final[int] = cv2.COLOR_YUV420p2BGR
COLOR_YUV420P2BGR: Final[int] = cv2.COLOR_YUV420P2BGR
COLOR_YUV2RGBA_YV12: Final[int] = cv2.COLOR_YUV2RGBA_YV12
COLOR_YUV2BGRA_YV12: Final[int] = cv2.COLOR_YUV2BGRA_YV12
COLOR_YUV2RGBA_IYUV: Final[int] = cv2.COLOR_YUV2RGBA_IYUV
COLOR_YUV2BGRA_IYUV: Final[int] = cv2.COLOR_YUV2BGRA_IYUV
COLOR_YUV2RGBA_I420: Final[int] = cv2.COLOR_YUV2RGBA_I420
COLOR_YUV2BGRA_I420: Final[int] = cv2.COLOR_YUV2BGRA_I420
COLOR_YUV420p2RGBA: Final[int] = cv2.COLOR_YUV420p2RGBA
COLOR_YUV420P2RGBA: Final[int] = cv2.COLOR_YUV420P2RGBA
COLOR_YUV420p2BGRA: Final[int] = cv2.COLOR_YUV420p2BGRA
COLOR_YUV420P2BGRA: Final[int] = cv2.COLOR_YUV420P2BGRA
COLOR_YUV2GRAY_420: Final[int] = cv2.COLOR_YUV2GRAY_420
COLOR_YUV2GRAY_NV21: Final[int] = cv2.COLOR_YUV2GRAY_NV21
COLOR_YUV2GRAY_NV12: Final[int] = cv2.COLOR_YUV2GRAY_NV12
COLOR_YUV2GRAY_YV12: Final[int] = cv2.COLOR_YUV2GRAY_YV12
COLOR_YUV2GRAY_IYUV: Final[int] = cv2.COLOR_YUV2GRAY_IYUV
COLOR_YUV2GRAY_I420: Final[int] = cv2.COLOR_YUV2GRAY_I420
COLOR_YUV420sp2GRAY: Final[int] = cv2.COLOR_YUV420sp2GRAY
COLOR_YUV420SP2GRAY: Final[int] = cv2.COLOR_YUV420SP2GRAY
COLOR_YUV420p2GRAY: Final[int] = cv2.COLOR_YUV420p2GRAY
COLOR_YUV420P2GRAY: Final[int] = cv2.COLOR_YUV420P2GRAY
COLOR_YUV2RGB_UYVY: Final[int] = cv2.COLOR_YUV2RGB_UYVY
COLOR_YUV2BGR_UYVY: Final[int] = cv2.COLOR_YUV2BGR_UYVY
COLOR_YUV2RGB_Y422: Final[int] = cv2.COLOR_YUV2RGB_Y422
COLOR_YUV2BGR_Y422: Final[int] = cv2.COLOR_YUV2BGR_Y422
COLOR_YUV2RGB_UYNV: Final[int] = cv2.COLOR_YUV2RGB_UYNV
COLOR_YUV2BGR_UYNV: Final[int] = cv2.COLOR_YUV2BGR_UYNV
COLOR_YUV2RGBA_UYVY: Final[int] = cv2.COLOR_YUV2RGBA_UYVY
COLOR_YUV2BGRA_UYVY: Final[int] = cv2.COLOR_YUV2BGRA_UYVY
COLOR_YUV2RGBA_Y422: Final[int] = cv2.COLOR_YUV2RGBA_Y422
COLOR_YUV2BGRA_Y422: Final[int] = cv2.COLOR_YUV2BGRA_Y422
COLOR_YUV2RGBA_UYNV: Final[int] = cv2.COLOR_YUV2RGBA_UYNV
COLOR_YUV2BGRA_UYNV: Final[int] = cv2.COLOR_YUV2BGRA_UYNV
COLOR_YUV2RGB_YUY2: Final[int] = cv2.COLOR_YUV2RGB_YUY2
COLOR_YUV2BGR_YUY2: Final[int] = cv2.COLOR_YUV2BGR_YUY2
COLOR_YUV2RGB_YVYU: Final[int] = cv2.COLOR_YUV2RGB_YVYU
COLOR_YUV2BGR_YVYU: Final[int] = cv2.COLOR_YUV2BGR_YVYU
COLOR_YUV2RGB_YUYV: Final[int] = cv2.COLOR_YUV2RGB_YUYV
COLOR_YUV2BGR_YUYV: Final[int] = cv2.COLOR_YUV2BGR_YUYV
COLOR_YUV2RGB_YUNV: Final[int] = cv2.COLOR_YUV2RGB_YUNV
COLOR_YUV2BGR_YUNV: Final[int] = cv2.COLOR_YUV2BGR_YUNV
COLOR_YUV2RGBA_YUY2: Final[int] = cv2.COLOR_YUV2RGBA_YUY2
COLOR_YUV2BGRA_YUY2: Final[int] = cv2.COLOR_YUV2BGRA_YUY2
COLOR_YUV2RGBA_YVYU: Final[int] = cv2.COLOR_YUV2RGBA_YVYU
COLOR_YUV2BGRA_YVYU: Final[int] = cv2.COLOR_YUV2BGRA_YVYU
COLOR_YUV2RGBA_YUYV: Final[int] = cv2.COLOR_YUV2RGBA_YUYV
COLOR_YUV2BGRA_YUYV: Final[int] = cv2.COLOR_YUV2BGRA_YUYV
COLOR_YUV2RGBA_YUNV: Final[int] = cv2.COLOR_YUV2RGBA_YUNV
COLOR_YUV2BGRA_YUNV: Final[int] = cv2.COLOR_YUV2BGRA_YUNV
COLOR_YUV2GRAY_UYVY: Final[int] = cv2.COLOR_YUV2GRAY_UYVY
COLOR_YUV2GRAY_YUY2: Final[int] = cv2.COLOR_YUV2GRAY_YUY2
COLOR_YUV2GRAY_Y422: Final[int] = cv2.COLOR_YUV2GRAY_Y422
COLOR_YUV2GRAY_UYNV: Final[int] = cv2.COLOR_YUV2GRAY_UYNV
COLOR_YUV2GRAY_YVYU: Final[int] = cv2.COLOR_YUV2GRAY_YVYU
COLOR_YUV2GRAY_YUYV: Final[int] = cv2.COLOR_YUV2GRAY_YUYV
COLOR_YUV2GRAY_YUNV: Final[int] = cv2.COLOR_YUV2GRAY_YUNV
COLOR_RGBA2mRGBA: Final[int] = cv2.COLOR_RGBA2mRGBA
COLOR_RGBA2M_RGBA: Final[int] = cv2.COLOR_RGBA2M_RGBA
COLOR_mRGBA2RGBA: Final[int] = cv2.COLOR_mRGBA2RGBA
COLOR_M_RGBA2RGBA: Final[int] = cv2.COLOR_M_RGBA2RGBA
COLOR_RGB2YUV_I420: Final[int] = cv2.COLOR_RGB2YUV_I420
COLOR_BGR2YUV_I420: Final[int] = cv2.COLOR_BGR2YUV_I420
COLOR_RGB2YUV_IYUV: Final[int] = cv2.COLOR_RGB2YUV_IYUV
COLOR_BGR2YUV_IYUV: Final[int] = cv2.COLOR_BGR2YUV_IYUV
COLOR_RGBA2YUV_I420: Final[int] = cv2.COLOR_RGBA2YUV_I420
COLOR_BGRA2YUV_I420: Final[int] = cv2.COLOR_BGRA2YUV_I420
COLOR_RGBA2YUV_IYUV: Final[int] = cv2.COLOR_RGBA2YUV_IYUV
COLOR_BGRA2YUV_IYUV: Final[int] = cv2.COLOR_BGRA2YUV_IYUV
COLOR_RGB2YUV_YV12: Final[int] = cv2.COLOR_RGB2YUV_YV12
COLOR_BGR2YUV_YV12: Final[int] = cv2.COLOR_BGR2YUV_YV12
COLOR_RGBA2YUV_YV12: Final[int] = cv2.COLOR_RGBA2YUV_YV12
COLOR_BGRA2YUV_YV12: Final[int] = cv2.COLOR_BGRA2YUV_YV12
COLOR_BayerBG2BGR: Final[int] = cv2.COLOR_BayerBG2BGR
COLOR_BAYER_BG2BGR: Final[int] = cv2.COLOR_BAYER_BG2BGR
COLOR_BayerGB2BGR: Final[int] = cv2.COLOR_BayerGB2BGR
COLOR_BAYER_GB2BGR: Final[int] = cv2.COLOR_BAYER_GB2BGR
COLOR_BayerRG2BGR: Final[int] = cv2.COLOR_BayerRG2BGR
COLOR_BAYER_RG2BGR: Final[int] = cv2.COLOR_BAYER_RG2BGR
COLOR_BayerGR2BGR: Final[int] = cv2.COLOR_BayerGR2BGR
COLOR_BAYER_GR2BGR: Final[int] = cv2.COLOR_BAYER_GR2BGR
COLOR_BayerRGGB2BGR: Final[int] = cv2.COLOR_BayerRGGB2BGR
COLOR_BAYER_RGGB2BGR: Final[int] = cv2.COLOR_BAYER_RGGB2BGR
COLOR_BayerGRBG2BGR: Final[int] = cv2.COLOR_BayerGRBG2BGR
COLOR_BAYER_GRBG2BGR: Final[int] = cv2.COLOR_BAYER_GRBG2BGR
COLOR_BayerBGGR2BGR: Final[int] = cv2.COLOR_BayerBGGR2BGR
COLOR_BAYER_BGGR2BGR: Final[int] = cv2.COLOR_BAYER_BGGR2BGR
COLOR_BayerGBRG2BGR: Final[int] = cv2.COLOR_BayerGBRG2BGR
COLOR_BAYER_GBRG2BGR: Final[int] = cv2.COLOR_BAYER_GBRG2BGR
COLOR_BayerRGGB2RGB: Final[int] = cv2.COLOR_BayerRGGB2RGB
COLOR_BAYER_RGGB2RGB: Final[int] = cv2.COLOR_BAYER_RGGB2RGB
COLOR_BayerGRBG2RGB: Final[int] = cv2.COLOR_BayerGRBG2RGB
COLOR_BAYER_GRBG2RGB: Final[int] = cv2.COLOR_BAYER_GRBG2RGB
COLOR_BayerBGGR2RGB: Final[int] = cv2.COLOR_BayerBGGR2RGB
COLOR_BAYER_BGGR2RGB: Final[int] = cv2.COLOR_BAYER_BGGR2RGB
COLOR_BayerGBRG2RGB: Final[int] = cv2.COLOR_BayerGBRG2RGB
COLOR_BAYER_GBRG2RGB: Final[int] = cv2.COLOR_BAYER_GBRG2RGB
COLOR_BayerBG2RGB: Final[int] = cv2.COLOR_BayerBG2RGB
COLOR_BAYER_BG2RGB: Final[int] = cv2.COLOR_BAYER_BG2RGB
COLOR_BayerGB2RGB: Final[int] = cv2.COLOR_BayerGB2RGB
COLOR_BAYER_GB2RGB: Final[int] = cv2.COLOR_BAYER_GB2RGB
COLOR_BayerRG2RGB: Final[int] = cv2.COLOR_BayerRG2RGB
COLOR_BAYER_RG2RGB: Final[int] = cv2.COLOR_BAYER_RG2RGB
COLOR_BayerGR2RGB: Final[int] = cv2.COLOR_BayerGR2RGB
COLOR_BAYER_GR2RGB: Final[int] = cv2.COLOR_BAYER_GR2RGB
COLOR_BayerBG2GRAY: Final[int] = cv2.COLOR_BayerBG2GRAY
COLOR_BAYER_BG2GRAY: Final[int] = cv2.COLOR_BAYER_BG2GRAY
COLOR_BayerGB2GRAY: Final[int] = cv2.COLOR_BayerGB2GRAY
COLOR_BAYER_GB2GRAY: Final[int] = cv2.COLOR_BAYER_GB2GRAY
COLOR_BayerRG2GRAY: Final[int] = cv2.COLOR_BayerRG2GRAY
COLOR_BAYER_RG2GRAY: Final[int] = cv2.COLOR_BAYER_RG2GRAY
COLOR_BayerGR2GRAY: Final[int] = cv2.COLOR_BayerGR2GRAY
COLOR_BAYER_GR2GRAY: Final[int] = cv2.COLOR_BAYER_GR2GRAY
COLOR_BayerRGGB2GRAY: Final[int] = cv2.COLOR_BayerRGGB2GRAY
COLOR_BAYER_RGGB2GRAY: Final[int] = cv2.COLOR_BAYER_RGGB2GRAY
COLOR_BayerGRBG2GRAY: Final[int] = cv2.COLOR_BayerGRBG2GRAY
COLOR_BAYER_GRBG2GRAY: Final[int] = cv2.COLOR_BAYER_GRBG2GRAY
COLOR_BayerBGGR2GRAY: Final[int] = cv2.COLOR_BayerBGGR2GRAY
COLOR_BAYER_BGGR2GRAY: Final[int] = cv2.COLOR_BAYER_BGGR2GRAY
COLOR_BayerGBRG2GRAY: Final[int] = cv2.COLOR_BayerGBRG2GRAY
COLOR_BAYER_GBRG2GRAY: Final[int] = cv2.COLOR_BAYER_GBRG2GRAY
COLOR_BayerBG2BGR_VNG: Final[int] = cv2.COLOR_BayerBG2BGR_VNG
COLOR_BAYER_BG2BGR_VNG: Final[int] = cv2.COLOR_BAYER_BG2BGR_VNG
COLOR_BayerGB2BGR_VNG: Final[int] = cv2.COLOR_BayerGB2BGR_VNG
COLOR_BAYER_GB2BGR_VNG: Final[int] = cv2.COLOR_BAYER_GB2BGR_VNG
COLOR_BayerRG2BGR_VNG: Final[int] = cv2.COLOR_BayerRG2BGR_VNG
COLOR_BAYER_RG2BGR_VNG: Final[int] = cv2.COLOR_BAYER_RG2BGR_VNG
COLOR_BayerGR2BGR_VNG: Final[int] = cv2.COLOR_BayerGR2BGR_VNG
COLOR_BAYER_GR2BGR_VNG: Final[int] = cv2.COLOR_BAYER_GR2BGR_VNG
COLOR_BayerRGGB2BGR_VNG: Final[int] = cv2.COLOR_BayerRGGB2BGR_VNG
COLOR_BAYER_RGGB2BGR_VNG: Final[int] = cv2.COLOR_BAYER_RGGB2BGR_VNG
COLOR_BayerGRBG2BGR_VNG: Final[int] = cv2.COLOR_BayerGRBG2BGR_VNG
COLOR_BAYER_GRBG2BGR_VNG: Final[int] = cv2.COLOR_BAYER_GRBG2BGR_VNG
COLOR_BayerBGGR2BGR_VNG: Final[int] = cv2.COLOR_BayerBGGR2BGR_VNG
COLOR_BAYER_BGGR2BGR_VNG: Final[int] = cv2.COLOR_BAYER_BGGR2BGR_VNG
COLOR_BayerGBRG2BGR_VNG: Final[int] = cv2.COLOR_BayerGBRG2BGR_VNG
COLOR_BAYER_GBRG2BGR_VNG: Final[int] = cv2.COLOR_BAYER_GBRG2BGR_VNG
COLOR_BayerRGGB2RGB_VNG: Final[int] = cv2.COLOR_BayerRGGB2RGB_VNG
COLOR_BAYER_RGGB2RGB_VNG: Final[int] = cv2.COLOR_BAYER_RGGB2RGB_VNG
COLOR_BayerGRBG2RGB_VNG: Final[int] = cv2.COLOR_BayerGRBG2RGB_VNG
COLOR_BAYER_GRBG2RGB_VNG: Final[int] = cv2.COLOR_BAYER_GRBG2RGB_VNG
COLOR_BayerBGGR2RGB_VNG: Final[int] = cv2.COLOR_BayerBGGR2RGB_VNG
COLOR_BAYER_BGGR2RGB_VNG: Final[int] = cv2.COLOR_BAYER_BGGR2RGB_VNG
COLOR_BayerGBRG2RGB_VNG: Final[int] = cv2.COLOR_BayerGBRG2RGB_VNG
COLOR_BAYER_GBRG2RGB_VNG: Final[int] = cv2.COLOR_BAYER_GBRG2RGB_VNG
COLOR_BayerBG2RGB_VNG: Final[int] = cv2.COLOR_BayerBG2RGB_VNG
COLOR_BAYER_BG2RGB_VNG: Final[int] = cv2.COLOR_BAYER_BG2RGB_VNG
COLOR_BayerGB2RGB_VNG: Final[int] = cv2.COLOR_BayerGB2RGB_VNG
COLOR_BAYER_GB2RGB_VNG: Final[int] = cv2.COLOR_BAYER_GB2RGB_VNG
COLOR_BayerRG2RGB_VNG: Final[int] = cv2.COLOR_BayerRG2RGB_VNG
COLOR_BAYER_RG2RGB_VNG: Final[int] = cv2.COLOR_BAYER_RG2RGB_VNG
COLOR_BayerGR2RGB_VNG: Final[int] = cv2.COLOR_BayerGR2RGB_VNG
COLOR_BAYER_GR2RGB_VNG: Final[int] = cv2.COLOR_BAYER_GR2RGB_VNG
COLOR_BayerBG2BGR_EA: Final[int] = cv2.COLOR_BayerBG2BGR_EA
COLOR_BAYER_BG2BGR_EA: Final[int] = cv2.COLOR_BAYER_BG2BGR_EA
COLOR_BayerGB2BGR_EA: Final[int] = cv2.COLOR_BayerGB2BGR_EA
COLOR_BAYER_GB2BGR_EA: Final[int] = cv2.COLOR_BAYER_GB2BGR_EA
COLOR_BayerRG2BGR_EA: Final[int] = cv2.COLOR_BayerRG2BGR_EA
COLOR_BAYER_RG2BGR_EA: Final[int] = cv2.COLOR_BAYER_RG2BGR_EA
COLOR_BayerGR2BGR_EA: Final[int] = cv2.COLOR_BayerGR2BGR_EA
COLOR_BAYER_GR2BGR_EA: Final[int] = cv2.COLOR_BAYER_GR2BGR_EA
COLOR_BayerRGGB2BGR_EA: Final[int] = cv2.COLOR_BayerRGGB2BGR_EA
COLOR_BAYER_RGGB2BGR_EA: Final[int] = cv2.COLOR_BAYER_RGGB2BGR_EA
COLOR_BayerGRBG2BGR_EA: Final[int] = cv2.COLOR_BayerGRBG2BGR_EA
COLOR_BAYER_GRBG2BGR_EA: Final[int] = cv2.COLOR_BAYER_GRBG2BGR_EA
COLOR_BayerBGGR2BGR_EA: Final[int] = cv2.COLOR_BayerBGGR2BGR_EA
COLOR_BAYER_BGGR2BGR_EA: Final[int] = cv2.COLOR_BAYER_BGGR2BGR_EA
COLOR_BayerGBRG2BGR_EA: Final[int] = cv2.COLOR_BayerGBRG2BGR_EA
COLOR_BAYER_GBRG2BGR_EA: Final[int] = cv2.COLOR_BAYER_GBRG2BGR_EA
COLOR_BayerRGGB2RGB_EA: Final[int] = cv2.COLOR_BayerRGGB2RGB_EA
COLOR_BAYER_RGGB2RGB_EA: Final[int] = cv2.COLOR_BAYER_RGGB2RGB_EA
COLOR_BayerGRBG2RGB_EA: Final[int] = cv2.COLOR_BayerGRBG2RGB_EA
COLOR_BAYER_GRBG2RGB_EA: Final[int] = cv2.COLOR_BAYER_GRBG2RGB_EA
COLOR_BayerBGGR2RGB_EA: Final[int] = cv2.COLOR_BayerBGGR2RGB_EA
COLOR_BAYER_BGGR2RGB_EA: Final[int] = cv2.COLOR_BAYER_BGGR2RGB_EA
COLOR_BayerGBRG2RGB_EA: Final[int] = cv2.COLOR_BayerGBRG2RGB_EA
COLOR_BAYER_GBRG2RGB_EA: Final[int] = cv2.COLOR_BAYER_GBRG2RGB_EA
COLOR_BayerBG2RGB_EA: Final[int] = cv2.COLOR_BayerBG2RGB_EA
COLOR_BAYER_BG2RGB_EA: Final[int] = cv2.COLOR_BAYER_BG2RGB_EA
COLOR_BayerGB2RGB_EA: Final[int] = cv2.COLOR_BayerGB2RGB_EA
COLOR_BAYER_GB2RGB_EA: Final[int] = cv2.COLOR_BAYER_GB2RGB_EA
COLOR_BayerRG2RGB_EA: Final[int] = cv2.COLOR_BayerRG2RGB_EA
COLOR_BAYER_RG2RGB_EA: Final[int] = cv2.COLOR_BAYER_RG2RGB_EA
COLOR_BayerGR2RGB_EA: Final[int] = cv2.COLOR_BayerGR2RGB_EA
COLOR_BAYER_GR2RGB_EA: Final[int] = cv2.COLOR_BAYER_GR2RGB_EA
COLOR_BayerBG2BGRA: Final[int] = cv2.COLOR_BayerBG2BGRA
COLOR_BAYER_BG2BGRA: Final[int] = cv2.COLOR_BAYER_BG2BGRA
COLOR_BayerGB2BGRA: Final[int] = cv2.COLOR_BayerGB2BGRA
COLOR_BAYER_GB2BGRA: Final[int] = cv2.COLOR_BAYER_GB2BGRA
COLOR_BayerRG2BGRA: Final[int] = cv2.COLOR_BayerRG2BGRA
COLOR_BAYER_RG2BGRA: Final[int] = cv2.COLOR_BAYER_RG2BGRA
COLOR_BayerGR2BGRA: Final[int] = cv2.COLOR_BayerGR2BGRA
COLOR_BAYER_GR2BGRA: Final[int] = cv2.COLOR_BAYER_GR2BGRA
COLOR_BayerRGGB2BGRA: Final[int] = cv2.COLOR_BayerRGGB2BGRA
COLOR_BAYER_RGGB2BGRA: Final[int] = cv2.COLOR_BAYER_RGGB2BGRA
COLOR_BayerGRBG2BGRA: Final[int] = cv2.COLOR_BayerGRBG2BGRA
COLOR_BAYER_GRBG2BGRA: Final[int] = cv2.COLOR_BAYER_GRBG2BGRA
COLOR_BayerBGGR2BGRA: Final[int] = cv2.COLOR_BayerBGGR2BGRA
COLOR_BAYER_BGGR2BGRA: Final[int] = cv2.COLOR_BAYER_BGGR2BGRA
COLOR_BayerGBRG2BGRA: Final[int] = cv2.COLOR_BayerGBRG2BGRA
COLOR_BAYER_GBRG2BGRA: Final[int] = cv2.COLOR_BAYER_GBRG2BGRA
COLOR_BayerRGGB2RGBA: Final[int] = cv2.COLOR_BayerRGGB2RGBA
COLOR_BAYER_RGGB2RGBA: Final[int] = cv2.COLOR_BAYER_RGGB2RGBA
COLOR_BayerGRBG2RGBA: Final[int] = cv2.COLOR_BayerGRBG2RGBA
COLOR_BAYER_GRBG2RGBA: Final[int] = cv2.COLOR_BAYER_GRBG2RGBA
COLOR_BayerBGGR2RGBA: Final[int] = cv2.COLOR_BayerBGGR2RGBA
COLOR_BAYER_BGGR2RGBA: Final[int] = cv2.COLOR_BAYER_BGGR2RGBA
COLOR_BayerGBRG2RGBA: Final[int] = cv2.COLOR_BayerGBRG2RGBA
COLOR_BAYER_GBRG2RGBA: Final[int] = cv2.COLOR_BAYER_GBRG2RGBA
COLOR_BayerBG2RGBA: Final[int] = cv2.COLOR_BayerBG2RGBA
COLOR_BAYER_BG2RGBA: Final[int] = cv2.COLOR_BAYER_BG2RGBA
COLOR_BayerGB2RGBA: Final[int] = cv2.COLOR_BayerGB2RGBA
COLOR_BAYER_GB2RGBA: Final[int] = cv2.COLOR_BAYER_GB2RGBA
COLOR_BayerRG2RGBA: Final[int] = cv2.COLOR_BayerRG2RGBA
COLOR_BAYER_RG2RGBA: Final[int] = cv2.COLOR_BAYER_RG2RGBA
COLOR_BayerGR2RGBA: Final[int] = cv2.COLOR_BayerGR2RGBA
COLOR_BAYER_GR2RGBA: Final[int] = cv2.COLOR_BAYER_GR2RGBA


class CvtColorCode(Enum):
    BGR2BGRA = COLOR_BGR2BGRA
    RGB2RGBA = COLOR_RGB2RGBA
    BGRA2BGR = COLOR_BGRA2BGR
    RGBA2RGB = COLOR_RGBA2RGB
    BGR2RGBA = COLOR_BGR2RGBA
    RGB2BGRA = COLOR_RGB2BGRA
    RGBA2BGR = COLOR_RGBA2BGR
    BGRA2RGB = COLOR_BGRA2RGB
    BGR2RGB = COLOR_BGR2RGB
    RGB2BGR = COLOR_RGB2BGR
    BGRA2RGBA = COLOR_BGRA2RGBA
    RGBA2BGRA = COLOR_RGBA2BGRA
    BGR2GRAY = COLOR_BGR2GRAY
    RGB2GRAY = COLOR_RGB2GRAY
    GRAY2BGR = COLOR_GRAY2BGR
    GRAY2RGB = COLOR_GRAY2RGB
    GRAY2BGRA = COLOR_GRAY2BGRA
    GRAY2RGBA = COLOR_GRAY2RGBA
    BGRA2GRAY = COLOR_BGRA2GRAY
    RGBA2GRAY = COLOR_RGBA2GRAY
    BGR2BGR565 = COLOR_BGR2BGR565
    RGB2BGR565 = COLOR_RGB2BGR565
    BGR5652BGR = COLOR_BGR5652BGR
    BGR5652RGB = COLOR_BGR5652RGB
    BGRA2BGR565 = COLOR_BGRA2BGR565
    RGBA2BGR565 = COLOR_RGBA2BGR565
    BGR5652BGRA = COLOR_BGR5652BGRA
    BGR5652RGBA = COLOR_BGR5652RGBA
    GRAY2BGR565 = COLOR_GRAY2BGR565
    BGR5652GRAY = COLOR_BGR5652GRAY
    BGR2BGR555 = COLOR_BGR2BGR555
    RGB2BGR555 = COLOR_RGB2BGR555
    BGR5552BGR = COLOR_BGR5552BGR
    BGR5552RGB = COLOR_BGR5552RGB
    BGRA2BGR555 = COLOR_BGRA2BGR555
    RGBA2BGR555 = COLOR_RGBA2BGR555
    BGR5552BGRA = COLOR_BGR5552BGRA
    BGR5552RGBA = COLOR_BGR5552RGBA
    GRAY2BGR555 = COLOR_GRAY2BGR555
    BGR5552GRAY = COLOR_BGR5552GRAY
    BGR2XYZ = COLOR_BGR2XYZ
    RGB2XYZ = COLOR_RGB2XYZ
    XYZ2BGR = COLOR_XYZ2BGR
    XYZ2RGB = COLOR_XYZ2RGB
    BGR2YCrCb = COLOR_BGR2YCrCb
    BGR2YCR_CB = COLOR_BGR2YCR_CB
    RGB2YCrCb = COLOR_RGB2YCrCb
    RGB2YCR_CB = COLOR_RGB2YCR_CB
    YCrCb2BGR = COLOR_YCrCb2BGR
    YCR_CB2BGR = COLOR_YCR_CB2BGR
    YCrCb2RGB = COLOR_YCrCb2RGB
    YCR_CB2RGB = COLOR_YCR_CB2RGB
    BGR2HSV = COLOR_BGR2HSV
    RGB2HSV = COLOR_RGB2HSV
    BGR2Lab = COLOR_BGR2Lab
    BGR2LAB = COLOR_BGR2LAB
    RGB2Lab = COLOR_RGB2Lab
    RGB2LAB = COLOR_RGB2LAB
    BGR2Luv = COLOR_BGR2Luv
    BGR2LUV = COLOR_BGR2LUV
    RGB2Luv = COLOR_RGB2Luv
    RGB2LUV = COLOR_RGB2LUV
    BGR2HLS = COLOR_BGR2HLS
    RGB2HLS = COLOR_RGB2HLS
    HSV2BGR = COLOR_HSV2BGR
    HSV2RGB = COLOR_HSV2RGB
    Lab2BGR = COLOR_Lab2BGR
    LAB2BGR = COLOR_LAB2BGR
    Lab2RGB = COLOR_Lab2RGB
    LAB2RGB = COLOR_LAB2RGB
    Luv2BGR = COLOR_Luv2BGR
    LUV2BGR = COLOR_LUV2BGR
    Luv2RGB = COLOR_Luv2RGB
    LUV2RGB = COLOR_LUV2RGB
    HLS2BGR = COLOR_HLS2BGR
    HLS2RGB = COLOR_HLS2RGB
    BGR2HSV_FULL = COLOR_BGR2HSV_FULL
    RGB2HSV_FULL = COLOR_RGB2HSV_FULL
    BGR2HLS_FULL = COLOR_BGR2HLS_FULL
    RGB2HLS_FULL = COLOR_RGB2HLS_FULL
    HSV2BGR_FULL = COLOR_HSV2BGR_FULL
    HSV2RGB_FULL = COLOR_HSV2RGB_FULL
    HLS2BGR_FULL = COLOR_HLS2BGR_FULL
    HLS2RGB_FULL = COLOR_HLS2RGB_FULL
    LBGR2Lab = COLOR_LBGR2Lab
    LBGR2LAB = COLOR_LBGR2LAB
    LRGB2Lab = COLOR_LRGB2Lab
    LRGB2LAB = COLOR_LRGB2LAB
    LBGR2Luv = COLOR_LBGR2Luv
    LBGR2LUV = COLOR_LBGR2LUV
    LRGB2Luv = COLOR_LRGB2Luv
    LRGB2LUV = COLOR_LRGB2LUV
    Lab2LBGR = COLOR_Lab2LBGR
    LAB2LBGR = COLOR_LAB2LBGR
    Lab2LRGB = COLOR_Lab2LRGB
    LAB2LRGB = COLOR_LAB2LRGB
    Luv2LBGR = COLOR_Luv2LBGR
    LUV2LBGR = COLOR_LUV2LBGR
    Luv2LRGB = COLOR_Luv2LRGB
    LUV2LRGB = COLOR_LUV2LRGB
    BGR2YUV = COLOR_BGR2YUV
    RGB2YUV = COLOR_RGB2YUV
    YUV2BGR = COLOR_YUV2BGR
    YUV2RGB = COLOR_YUV2RGB
    YUV2RGB_NV12 = COLOR_YUV2RGB_NV12
    YUV2BGR_NV12 = COLOR_YUV2BGR_NV12
    YUV2RGB_NV21 = COLOR_YUV2RGB_NV21
    YUV2BGR_NV21 = COLOR_YUV2BGR_NV21
    YUV420sp2RGB = COLOR_YUV420sp2RGB
    YUV420SP2RGB = COLOR_YUV420SP2RGB
    YUV420sp2BGR = COLOR_YUV420sp2BGR
    YUV420SP2BGR = COLOR_YUV420SP2BGR
    YUV2RGBA_NV12 = COLOR_YUV2RGBA_NV12
    YUV2BGRA_NV12 = COLOR_YUV2BGRA_NV12
    YUV2RGBA_NV21 = COLOR_YUV2RGBA_NV21
    YUV2BGRA_NV21 = COLOR_YUV2BGRA_NV21
    YUV420sp2RGBA = COLOR_YUV420sp2RGBA
    YUV420SP2RGBA = COLOR_YUV420SP2RGBA
    YUV420sp2BGRA = COLOR_YUV420sp2BGRA
    YUV420SP2BGRA = COLOR_YUV420SP2BGRA
    YUV2RGB_YV12 = COLOR_YUV2RGB_YV12
    YUV2BGR_YV12 = COLOR_YUV2BGR_YV12
    YUV2RGB_IYUV = COLOR_YUV2RGB_IYUV
    YUV2BGR_IYUV = COLOR_YUV2BGR_IYUV
    YUV2RGB_I420 = COLOR_YUV2RGB_I420
    YUV2BGR_I420 = COLOR_YUV2BGR_I420
    YUV420p2RGB = COLOR_YUV420p2RGB
    YUV420P2RGB = COLOR_YUV420P2RGB
    YUV420p2BGR = COLOR_YUV420p2BGR
    YUV420P2BGR = COLOR_YUV420P2BGR
    YUV2RGBA_YV12 = COLOR_YUV2RGBA_YV12
    YUV2BGRA_YV12 = COLOR_YUV2BGRA_YV12
    YUV2RGBA_IYUV = COLOR_YUV2RGBA_IYUV
    YUV2BGRA_IYUV = COLOR_YUV2BGRA_IYUV
    YUV2RGBA_I420 = COLOR_YUV2RGBA_I420
    YUV2BGRA_I420 = COLOR_YUV2BGRA_I420
    YUV420p2RGBA = COLOR_YUV420p2RGBA
    YUV420P2RGBA = COLOR_YUV420P2RGBA
    YUV420p2BGRA = COLOR_YUV420p2BGRA
    YUV420P2BGRA = COLOR_YUV420P2BGRA
    YUV2GRAY_420 = COLOR_YUV2GRAY_420
    YUV2GRAY_NV21 = COLOR_YUV2GRAY_NV21
    YUV2GRAY_NV12 = COLOR_YUV2GRAY_NV12
    YUV2GRAY_YV12 = COLOR_YUV2GRAY_YV12
    YUV2GRAY_IYUV = COLOR_YUV2GRAY_IYUV
    YUV2GRAY_I420 = COLOR_YUV2GRAY_I420
    YUV420sp2GRAY = COLOR_YUV420sp2GRAY
    YUV420SP2GRAY = COLOR_YUV420SP2GRAY
    YUV420p2GRAY = COLOR_YUV420p2GRAY
    YUV420P2GRAY = COLOR_YUV420P2GRAY
    YUV2RGB_UYVY = COLOR_YUV2RGB_UYVY
    YUV2BGR_UYVY = COLOR_YUV2BGR_UYVY
    YUV2RGB_Y422 = COLOR_YUV2RGB_Y422
    YUV2BGR_Y422 = COLOR_YUV2BGR_Y422
    YUV2RGB_UYNV = COLOR_YUV2RGB_UYNV
    YUV2BGR_UYNV = COLOR_YUV2BGR_UYNV
    YUV2RGBA_UYVY = COLOR_YUV2RGBA_UYVY
    YUV2BGRA_UYVY = COLOR_YUV2BGRA_UYVY
    YUV2RGBA_Y422 = COLOR_YUV2RGBA_Y422
    YUV2BGRA_Y422 = COLOR_YUV2BGRA_Y422
    YUV2RGBA_UYNV = COLOR_YUV2RGBA_UYNV
    YUV2BGRA_UYNV = COLOR_YUV2BGRA_UYNV
    YUV2RGB_YUY2 = COLOR_YUV2RGB_YUY2
    YUV2BGR_YUY2 = COLOR_YUV2BGR_YUY2
    YUV2RGB_YVYU = COLOR_YUV2RGB_YVYU
    YUV2BGR_YVYU = COLOR_YUV2BGR_YVYU
    YUV2RGB_YUYV = COLOR_YUV2RGB_YUYV
    YUV2BGR_YUYV = COLOR_YUV2BGR_YUYV
    YUV2RGB_YUNV = COLOR_YUV2RGB_YUNV
    YUV2BGR_YUNV = COLOR_YUV2BGR_YUNV
    YUV2RGBA_YUY2 = COLOR_YUV2RGBA_YUY2
    YUV2BGRA_YUY2 = COLOR_YUV2BGRA_YUY2
    YUV2RGBA_YVYU = COLOR_YUV2RGBA_YVYU
    YUV2BGRA_YVYU = COLOR_YUV2BGRA_YVYU
    YUV2RGBA_YUYV = COLOR_YUV2RGBA_YUYV
    YUV2BGRA_YUYV = COLOR_YUV2BGRA_YUYV
    YUV2RGBA_YUNV = COLOR_YUV2RGBA_YUNV
    YUV2BGRA_YUNV = COLOR_YUV2BGRA_YUNV
    YUV2GRAY_UYVY = COLOR_YUV2GRAY_UYVY
    YUV2GRAY_YUY2 = COLOR_YUV2GRAY_YUY2
    YUV2GRAY_Y422 = COLOR_YUV2GRAY_Y422
    YUV2GRAY_UYNV = COLOR_YUV2GRAY_UYNV
    YUV2GRAY_YVYU = COLOR_YUV2GRAY_YVYU
    YUV2GRAY_YUYV = COLOR_YUV2GRAY_YUYV
    YUV2GRAY_YUNV = COLOR_YUV2GRAY_YUNV
    RGBA2mRGBA = COLOR_RGBA2mRGBA
    RGBA2M_RGBA = COLOR_RGBA2M_RGBA
    mRGBA2RGBA = COLOR_mRGBA2RGBA
    M_RGBA2RGBA = COLOR_M_RGBA2RGBA
    RGB2YUV_I420 = COLOR_RGB2YUV_I420
    BGR2YUV_I420 = COLOR_BGR2YUV_I420
    RGB2YUV_IYUV = COLOR_RGB2YUV_IYUV
    BGR2YUV_IYUV = COLOR_BGR2YUV_IYUV
    RGBA2YUV_I420 = COLOR_RGBA2YUV_I420
    BGRA2YUV_I420 = COLOR_BGRA2YUV_I420
    RGBA2YUV_IYUV = COLOR_RGBA2YUV_IYUV
    BGRA2YUV_IYUV = COLOR_BGRA2YUV_IYUV
    RGB2YUV_YV12 = COLOR_RGB2YUV_YV12
    BGR2YUV_YV12 = COLOR_BGR2YUV_YV12
    RGBA2YUV_YV12 = COLOR_RGBA2YUV_YV12
    BGRA2YUV_YV12 = COLOR_BGRA2YUV_YV12
    BayerBG2BGR = COLOR_BayerBG2BGR
    BAYER_BG2BGR = COLOR_BAYER_BG2BGR
    BayerGB2BGR = COLOR_BayerGB2BGR
    BAYER_GB2BGR = COLOR_BAYER_GB2BGR
    BayerRG2BGR = COLOR_BayerRG2BGR
    BAYER_RG2BGR = COLOR_BAYER_RG2BGR
    BayerGR2BGR = COLOR_BayerGR2BGR
    BAYER_GR2BGR = COLOR_BAYER_GR2BGR
    BayerRGGB2BGR = COLOR_BayerRGGB2BGR
    BAYER_RGGB2BGR = COLOR_BAYER_RGGB2BGR
    BayerGRBG2BGR = COLOR_BayerGRBG2BGR
    BAYER_GRBG2BGR = COLOR_BAYER_GRBG2BGR
    BayerBGGR2BGR = COLOR_BayerBGGR2BGR
    BAYER_BGGR2BGR = COLOR_BAYER_BGGR2BGR
    BayerGBRG2BGR = COLOR_BayerGBRG2BGR
    BAYER_GBRG2BGR = COLOR_BAYER_GBRG2BGR
    BayerRGGB2RGB = COLOR_BayerRGGB2RGB
    BAYER_RGGB2RGB = COLOR_BAYER_RGGB2RGB
    BayerGRBG2RGB = COLOR_BayerGRBG2RGB
    BAYER_GRBG2RGB = COLOR_BAYER_GRBG2RGB
    BayerBGGR2RGB = COLOR_BayerBGGR2RGB
    BAYER_BGGR2RGB = COLOR_BAYER_BGGR2RGB
    BayerGBRG2RGB = COLOR_BayerGBRG2RGB
    BAYER_GBRG2RGB = COLOR_BAYER_GBRG2RGB
    BayerBG2RGB = COLOR_BayerBG2RGB
    BAYER_BG2RGB = COLOR_BAYER_BG2RGB
    BayerGB2RGB = COLOR_BayerGB2RGB
    BAYER_GB2RGB = COLOR_BAYER_GB2RGB
    BayerRG2RGB = COLOR_BayerRG2RGB
    BAYER_RG2RGB = COLOR_BAYER_RG2RGB
    BayerGR2RGB = COLOR_BayerGR2RGB
    BAYER_GR2RGB = COLOR_BAYER_GR2RGB
    BayerBG2GRAY = COLOR_BayerBG2GRAY
    BAYER_BG2GRAY = COLOR_BAYER_BG2GRAY
    BayerGB2GRAY = COLOR_BayerGB2GRAY
    BAYER_GB2GRAY = COLOR_BAYER_GB2GRAY
    BayerRG2GRAY = COLOR_BayerRG2GRAY
    BAYER_RG2GRAY = COLOR_BAYER_RG2GRAY
    BayerGR2GRAY = COLOR_BayerGR2GRAY
    BAYER_GR2GRAY = COLOR_BAYER_GR2GRAY
    BayerRGGB2GRAY = COLOR_BayerRGGB2GRAY
    BAYER_RGGB2GRAY = COLOR_BAYER_RGGB2GRAY
    BayerGRBG2GRAY = COLOR_BayerGRBG2GRAY
    BAYER_GRBG2GRAY = COLOR_BAYER_GRBG2GRAY
    BayerBGGR2GRAY = COLOR_BayerBGGR2GRAY
    BAYER_BGGR2GRAY = COLOR_BAYER_BGGR2GRAY
    BayerGBRG2GRAY = COLOR_BayerGBRG2GRAY
    BAYER_GBRG2GRAY = COLOR_BAYER_GBRG2GRAY
    BayerBG2BGR_VNG = COLOR_BayerBG2BGR_VNG
    BAYER_BG2BGR_VNG = COLOR_BAYER_BG2BGR_VNG
    BayerGB2BGR_VNG = COLOR_BayerGB2BGR_VNG
    BAYER_GB2BGR_VNG = COLOR_BAYER_GB2BGR_VNG
    BayerRG2BGR_VNG = COLOR_BayerRG2BGR_VNG
    BAYER_RG2BGR_VNG = COLOR_BAYER_RG2BGR_VNG
    BayerGR2BGR_VNG = COLOR_BayerGR2BGR_VNG
    BAYER_GR2BGR_VNG = COLOR_BAYER_GR2BGR_VNG
    BayerRGGB2BGR_VNG = COLOR_BayerRGGB2BGR_VNG
    BAYER_RGGB2BGR_VNG = COLOR_BAYER_RGGB2BGR_VNG
    BayerGRBG2BGR_VNG = COLOR_BayerGRBG2BGR_VNG
    BAYER_GRBG2BGR_VNG = COLOR_BAYER_GRBG2BGR_VNG
    BayerBGGR2BGR_VNG = COLOR_BayerBGGR2BGR_VNG
    BAYER_BGGR2BGR_VNG = COLOR_BAYER_BGGR2BGR_VNG
    BayerGBRG2BGR_VNG = COLOR_BayerGBRG2BGR_VNG
    BAYER_GBRG2BGR_VNG = COLOR_BAYER_GBRG2BGR_VNG
    BayerRGGB2RGB_VNG = COLOR_BayerRGGB2RGB_VNG
    BAYER_RGGB2RGB_VNG = COLOR_BAYER_RGGB2RGB_VNG
    BayerGRBG2RGB_VNG = COLOR_BayerGRBG2RGB_VNG
    BAYER_GRBG2RGB_VNG = COLOR_BAYER_GRBG2RGB_VNG
    BayerBGGR2RGB_VNG = COLOR_BayerBGGR2RGB_VNG
    BAYER_BGGR2RGB_VNG = COLOR_BAYER_BGGR2RGB_VNG
    BayerGBRG2RGB_VNG = COLOR_BayerGBRG2RGB_VNG
    BAYER_GBRG2RGB_VNG = COLOR_BAYER_GBRG2RGB_VNG
    BayerBG2RGB_VNG = COLOR_BayerBG2RGB_VNG
    BAYER_BG2RGB_VNG = COLOR_BAYER_BG2RGB_VNG
    BayerGB2RGB_VNG = COLOR_BayerGB2RGB_VNG
    BAYER_GB2RGB_VNG = COLOR_BAYER_GB2RGB_VNG
    BayerRG2RGB_VNG = COLOR_BayerRG2RGB_VNG
    BAYER_RG2RGB_VNG = COLOR_BAYER_RG2RGB_VNG
    BayerGR2RGB_VNG = COLOR_BayerGR2RGB_VNG
    BAYER_GR2RGB_VNG = COLOR_BAYER_GR2RGB_VNG
    BayerBG2BGR_EA = COLOR_BayerBG2BGR_EA
    BAYER_BG2BGR_EA = COLOR_BAYER_BG2BGR_EA
    BayerGB2BGR_EA = COLOR_BayerGB2BGR_EA
    BAYER_GB2BGR_EA = COLOR_BAYER_GB2BGR_EA
    BayerRG2BGR_EA = COLOR_BayerRG2BGR_EA
    BAYER_RG2BGR_EA = COLOR_BAYER_RG2BGR_EA
    BayerGR2BGR_EA = COLOR_BayerGR2BGR_EA
    BAYER_GR2BGR_EA = COLOR_BAYER_GR2BGR_EA
    BayerRGGB2BGR_EA = COLOR_BayerRGGB2BGR_EA
    BAYER_RGGB2BGR_EA = COLOR_BAYER_RGGB2BGR_EA
    BayerGRBG2BGR_EA = COLOR_BayerGRBG2BGR_EA
    BAYER_GRBG2BGR_EA = COLOR_BAYER_GRBG2BGR_EA
    BayerBGGR2BGR_EA = COLOR_BayerBGGR2BGR_EA
    BAYER_BGGR2BGR_EA = COLOR_BAYER_BGGR2BGR_EA
    BayerGBRG2BGR_EA = COLOR_BayerGBRG2BGR_EA
    BAYER_GBRG2BGR_EA = COLOR_BAYER_GBRG2BGR_EA
    BayerRGGB2RGB_EA = COLOR_BayerRGGB2RGB_EA
    BAYER_RGGB2RGB_EA = COLOR_BAYER_RGGB2RGB_EA
    BayerGRBG2RGB_EA = COLOR_BayerGRBG2RGB_EA
    BAYER_GRBG2RGB_EA = COLOR_BAYER_GRBG2RGB_EA
    BayerBGGR2RGB_EA = COLOR_BayerBGGR2RGB_EA
    BAYER_BGGR2RGB_EA = COLOR_BAYER_BGGR2RGB_EA
    BayerGBRG2RGB_EA = COLOR_BayerGBRG2RGB_EA
    BAYER_GBRG2RGB_EA = COLOR_BAYER_GBRG2RGB_EA
    BayerBG2RGB_EA = COLOR_BayerBG2RGB_EA
    BAYER_BG2RGB_EA = COLOR_BAYER_BG2RGB_EA
    BayerGB2RGB_EA = COLOR_BayerGB2RGB_EA
    BAYER_GB2RGB_EA = COLOR_BAYER_GB2RGB_EA
    BayerRG2RGB_EA = COLOR_BayerRG2RGB_EA
    BAYER_RG2RGB_EA = COLOR_BAYER_RG2RGB_EA
    BayerGR2RGB_EA = COLOR_BayerGR2RGB_EA
    BAYER_GR2RGB_EA = COLOR_BAYER_GR2RGB_EA
    BayerBG2BGRA = COLOR_BayerBG2BGRA
    BAYER_BG2BGRA = COLOR_BAYER_BG2BGRA
    BayerGB2BGRA = COLOR_BayerGB2BGRA
    BAYER_GB2BGRA = COLOR_BAYER_GB2BGRA
    BayerRG2BGRA = COLOR_BayerRG2BGRA
    BAYER_RG2BGRA = COLOR_BAYER_RG2BGRA
    BayerGR2BGRA = COLOR_BayerGR2BGRA
    BAYER_GR2BGRA = COLOR_BAYER_GR2BGRA
    BayerRGGB2BGRA = COLOR_BayerRGGB2BGRA
    BAYER_RGGB2BGRA = COLOR_BAYER_RGGB2BGRA
    BayerGRBG2BGRA = COLOR_BayerGRBG2BGRA
    BAYER_GRBG2BGRA = COLOR_BAYER_GRBG2BGRA
    BayerBGGR2BGRA = COLOR_BayerBGGR2BGRA
    BAYER_BGGR2BGRA = COLOR_BAYER_BGGR2BGRA
    BayerGBRG2BGRA = COLOR_BayerGBRG2BGRA
    BAYER_GBRG2BGRA = COLOR_BAYER_GBRG2BGRA
    BayerRGGB2RGBA = COLOR_BayerRGGB2RGBA
    BAYER_RGGB2RGBA = COLOR_BAYER_RGGB2RGBA
    BayerGRBG2RGBA = COLOR_BayerGRBG2RGBA
    BAYER_GRBG2RGBA = COLOR_BAYER_GRBG2RGBA
    BayerBGGR2RGBA = COLOR_BayerBGGR2RGBA
    BAYER_BGGR2RGBA = COLOR_BAYER_BGGR2RGBA
    BayerGBRG2RGBA = COLOR_BayerGBRG2RGBA
    BAYER_GBRG2RGBA = COLOR_BAYER_GBRG2RGBA
    BayerBG2RGBA = COLOR_BayerBG2RGBA
    BAYER_BG2RGBA = COLOR_BAYER_BG2RGBA
    BayerGB2RGBA = COLOR_BayerGB2RGBA
    BAYER_GB2RGBA = COLOR_BAYER_GB2RGBA
    BayerRG2RGBA = COLOR_BayerRG2RGBA
    BAYER_RG2RGBA = COLOR_BAYER_RG2RGBA
    BayerGR2RGBA = COLOR_BayerGR2RGBA
    BAYER_GR2RGBA = COLOR_BAYER_GR2RGBA


CvtColorCodeLike = Union[CvtColorCode, str, int]

CVT_COLOR_CODE_MAP: Final[Dict[str, CvtColorCode]] = make_name_map(CvtColorCode, False)

assert COLOR_BGR2YCrCb == COLOR_BGR2YCR_CB
assert COLOR_RGB2YCrCb == COLOR_RGB2YCR_CB
assert COLOR_YCrCb2BGR == COLOR_YCR_CB2BGR
assert COLOR_YCrCb2RGB == COLOR_YCR_CB2RGB


def normalize_cvt_color_code(code: CvtColorCodeLike) -> int:
    if isinstance(code, CvtColorCode):
        return code.value
    elif isinstance(code, str):
        return CVT_COLOR_CODE_MAP[code].value
    elif isinstance(code, int):
        return code
    else:
        raise TypeError(f"Unsupported code type: {type(code).__name__}")
